
/*******************************************************************************
*  Description:
*    This project is just a sample program to test the color graphics display
*    shield component for the Cypress PSoC 4 and 5LP.  It executes most of the
*    commands in the color graphics shield component so the user can get an
*    idea in how to use the component
*
*    v1.0 4-30-2013  MEH  Initial project.
*
* Note:  This code has been tested with the Philips PCF8833 controller, but not
*        with the EPSON S115D10 version of the controller as of version 0.3 of the
*        SF_ColorShield (Color Graphics Shield) component.
*
*******************************************************************************
* The following firmware was developed by Cypress Semiconductor
* This work is licensed under a Creative Commons Attribution 3.0 Unported License.
*
* http://creativecommons.org/licenses/by/3.0/deed.en_US
* 
* You are free to:
* -To Share — to copy, distribute and transmit the work 
* -To Remix — to adapt the work 
* -To make commercial use of the work
*
* Much of this code was ported from the LCD_driver code by Mark Sproul
* and Peter DavenPort.  Also the tutorial by James P. Lynch
* on how the controller works was invaluable.
********************************************************************************/

#include <device.h>


/* An array of pixels to print on the LCD  */
#define PIXELCNT 10
int32 pixels[PIXELCNT][3] = {
              /* X,  Y,  Color   */
              { 91, 91, GLCD_BLUE },
			  { 96, 98, GLCD_YELLOW},
			  { 92, 95, GLCD_GREEN},
			  { 97, 93, GLCD_PURPLE},
			  { 94, 94, GLCD_RED },
			  { 92, 96, GLCD_RED },
			  { 95, 92, GLCD_YELLOW },
			  { 98, 97, GLCD_YELLOW },
			  { 93, 99, GLCD_BLUE },
			  { 99, 96, GLCD_GREEN }
			  };
			  
void main()
{
    uint32 i;
	
	/* Initialize LCD  */
    GLCD_Start();  
	GLCD_On();
  	GLCD_Contrast(60);  
  	GLCD_Clear(GLCD_BLACK);   /* Make background black  */ 

    /* Blue text with white background  */
	GLCD_PrintString(" Hello PSoC 4 ", 5, 8, GLCD_BLUE, GLCD_WHITE);

	/* Draw four unfilled rectangles at bottom of screen */
    GLCD_DrawRect(78, 8,102, 22, 0, GLCD_GREEN);
	GLCD_DrawRect(78,28,102, 42, 0, GLCD_BLUE);
	GLCD_DrawRect(78,48,102, 62, 0, GLCD_YELLOW);
	GLCD_DrawRect(78,68,102, 82, 0, GLCD_RED);
	
    /* Four color filed rectangles  */
	GLCD_DrawRect(80,10,100, 20, 1, GLCD_GREEN);
	GLCD_DrawRect(80,30,100, 40, 1, GLCD_BLUE);
	GLCD_DrawRect(80,50,100, 60, 1, GLCD_YELLOW);
	GLCD_DrawRect(80,70,100, 80, 1, GLCD_RED);
	
	/* Green text with black background */ 
	GLCD_PrintString("1234", 40,  10, GLCD_GREEN, GLCD_BLACK);
	
	/* Horizontal Green line */
	GLCD_DrawLine(65, 10, 65, 50, GLCD_GREEN);
	
	/* Vertical Red line */
	GLCD_DrawLine(30, 65, 60, 65, GLCD_RED);
	
	/* Diagonal White line */
	GLCD_DrawLine(65, 70, 90, 115, GLCD_WHITE);
	
	/* Four concentric circles  */
    GLCD_DrawCircle (50, 95, 20, GLCD_RED );
	GLCD_DrawCircle (50, 95, 15, GLCD_WHITE );
	GLCD_DrawCircle (50, 95, 10, GLCD_GREEN );
	GLCD_DrawCircle (50, 95,  5, GLCD_YELLOW );
	
	/* Green text on blue background in a red rectangle */
	GLCD_DrawRect(107, 30, 129, 92, 0, GLCD_RED);
    GLCD_PrintString("ABCDEFG", 108,  32, GLCD_GREEN, GLCD_BLUE);	

   /* Put array of pixels in a box  */
    GLCD_DrawRect(90, 90, 100, 100, 0, GLCD_WHITE);
    for (i= 0; i < PIXELCNT; i++)
	{
		GLCD_Pixel(pixels[i][0],pixels[i][1], pixels[i][2] );
	}
	
	CyDelay(5000);
	/* Turn off display */
	/* GLCD_Stop(); */
	
    for(;;)
    {
        /* Loop forever */   
    }
}

/* [] END OF FILE */
